@@ -8,6 +8,7 @@ import files_sdk.models.app as app
 import files_sdk.models.as2_key as as2_key
 import files_sdk.models.auto as auto
 import files_sdk.models.automation as automation
+import files_sdk.models.automation_run as automation_run
 import files_sdk.models.bandwidth_snapshot as bandwidth_snapshot
 import files_sdk.models.behavior as behavior
 import files_sdk.models.bundle as bundle
@@ -49,6 +50,7 @@ import files_sdk.models.payment as payment
 import files_sdk.models.payment_line_item as payment_line_item
 import files_sdk.models.permission as permission
 import files_sdk.models.preview as preview
+import files_sdk.models.priority as priority
 import files_sdk.models.project as project
 import files_sdk.models.public_ip_address as public_ip_address
 import files_sdk.models.public_key as public_key
@@ -78,6 +80,7 @@ from files_sdk.models.app import App
 from files_sdk.models.as2_key import As2Key
 from files_sdk.models.auto import Auto
 from files_sdk.models.automation import Automation
+from files_sdk.models.automation_run import AutomationRun
 from files_sdk.models.bandwidth_snapshot import BandwidthSnapshot
 from files_sdk.models.behavior import Behavior
 from files_sdk.models.bundle import Bundle
@@ -119,6 +122,7 @@ from files_sdk.models.payment import Payment
 from files_sdk.models.payment_line_item import PaymentLineItem
 from files_sdk.models.permission import Permission
 from files_sdk.models.preview import Preview
+from files_sdk.models.priority import Priority
 from files_sdk.models.project import Project
 from files_sdk.models.public_ip_address import PublicIpAddress
 from files_sdk.models.public_key import PublicKey
