@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -8,7 +9,7 @@ class App:
         'name': None,     # string - Name of the App
         'extended_description': None,     # string - Long form description of the App
         'short_description': None,     # string - Short description of the App
-        'documentation_links': None,     # string - Collection of named links to documentation
+        'documentation_links': None,     # object - Collection of named links to documentation
         'icon_url': None,     # string - App icon
         'logo_url': None,     # string - Full size logo for the App
         'screenshot_list_urls': None,     # string - Screenshots of the App
@@ -40,15 +41,15 @@ class App:
 
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `name` and `app_type`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `name` and `app_type`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `name` and `app_type`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `name` and `app_type`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `name` and `app_type`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `name` and `app_type`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `name` and `app_type`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `name` and `app_type`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `name` and `app_type`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `name` and `app_type`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `name` and `app_type`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `name` and `app_type`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `name` and `app_type`.
 def list(params = None, options = None):
     if not isinstance(params, dict):
         params = {}
