@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -27,15 +28,15 @@ class BundleDownload:
 
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `created_at`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `created_at`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `created_at`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `created_at`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `created_at`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `created_at`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `created_at`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `created_at`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `created_at`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `created_at`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `created_at`.
 #   bundle_id - int64 - Bundle ID
 #   bundle_registration_id - int64 - BundleRegistration ID
 def list(params = None, options = None):
