@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.models.usage_snapshot import UsageSnapshot
 from files_sdk.api import Api
@@ -18,6 +19,8 @@ class Site:
         'bundle_expiration': None,     # int64 - Site-wide Bundle expiration in days
         'bundle_password_required': None,     # boolean - Do Bundles require password protection?
         'bundle_require_share_recipient': None,     # boolean - Do Bundles require recipients for sharing?
+        'bundle_watermark_attachment': None,     # Preview watermark image applied to all bundle items.
+        'bundle_watermark_value': None,     # object - Preview watermark settings applied to all bundle items. Uses the same keys as Behavior.value
         'color2_left': None,     # string - Page link and button color
         'color2_link': None,     # string - Top bar link color
         'color2_text': None,     # string - Page link and button color
@@ -39,6 +42,8 @@ class Site:
         'disable_notifications': None,     # boolean - Are notifications disabled?
         'disable_password_reset': None,     # boolean - Is password reset disabled?
         'domain': None,     # string - Custom domain
+        'domain_hsts_header': None,     # boolean - Send HSTS (HTTP Strict Transport Security) header when visitors access the site via a custom domain?
+        'domain_letsencrypt_chain': None,     # string - Letsencrypt chain to use when registering SSL Certificate for domain.
         'email': None,     # email - Main email for this site
         'ftp_enabled': None,     # boolean - Is FTP enabled?
         'reply_to_email': None,     # email - Reply-to email for this site
@@ -95,6 +100,7 @@ class Site:
         'session': None,     # Current session
         'session_pinned_by_ip': None,     # boolean - Are sessions locked to the same IP? (i.e. do users need to log in again if they change IPs?)
         'sftp_enabled': None,     # boolean - Is SFTP enabled?
+        'sftp_insecure_ciphers': None,     # boolean - Are Insecure Ciphers allowed for SFTP?  Note:  Settting TLS Disabled -> True will always allow insecure ciphers for SFTP as well.  Enabling this is insecure.
         'sftp_user_root_enabled': None,     # boolean - Use user FTP roots also for SFTP?
         'sharing_enabled': None,     # boolean - Allow bundle creation
         'show_request_access_link': None,     # boolean - Show request access link for users without access?  Currently unused.
@@ -109,7 +115,7 @@ class Site:
         'ssl_required': None,     # boolean - Is SSL required?  Disabling this is insecure.
         'subdomain': None,     # string - Site subdomain
         'switch_to_plan_date': None,     # date-time - If switching plans, when does the new plan take effect?
-        'tls_disabled': None,     # boolean - Is TLS disabled(site setting)?
+        'tls_disabled': None,     # boolean - Are Insecure TLS and SFTP Ciphers allowed?  Enabling this is insecure.
         'trial_days_left': None,     # int64 - Number of days left in trial
         'trial_until': None,     # date-time - When does this Site trial expire?
         'updated_at': None,     # date-time - Last time this Site was updated
@@ -164,6 +170,8 @@ def get_usage(params = None, options = None):
 #   name - string - Site name
 #   subdomain - string - Site subdomain
 #   domain - string - Custom domain
+#   domain_hsts_header - boolean - Send HSTS (HTTP Strict Transport Security) header when visitors access the site via a custom domain?
+#   domain_letsencrypt_chain - string - Letsencrypt chain to use when registering SSL Certificate for domain.
 #   email - string - Main email for this site
 #   reply_to_email - string - Reply-to email for this site
 #   allow_bundle_names - boolean - Are manual Bundle names allowed?
@@ -188,7 +196,8 @@ def get_usage(params = None, options = None):
 #   office_integration_available - boolean - Allow users to use Office for the web?
 #   session_expiry - double - Session expiry in hours
 #   ssl_required - boolean - Is SSL required?  Disabling this is insecure.
-#   tls_disabled - boolean - Is TLS disabled(site setting)?
+#   tls_disabled - boolean - Are Insecure TLS and SFTP Ciphers allowed?  Enabling this is insecure.
+#   sftp_insecure_ciphers - boolean - Are Insecure Ciphers allowed for SFTP?  Note:  Settting TLS Disabled -> True will always allow insecure ciphers for SFTP as well.  Enabling this is insecure.
 #   user_lockout - boolean - Will users be locked out after incorrect login attempts?
 #   user_lockout_tries - int64 - Number of login tries within `user_lockout_within` hours before users are locked out
 #   user_lockout_within - int64 - Number of hours for user lockout window
@@ -268,6 +277,8 @@ def get_usage(params = None, options = None):
 #   icon128_delete - boolean - If true, will delete the file stored in icon128
 #   logo_file - file
 #   logo_delete - boolean - If true, will delete the file stored in logo
+#   bundle_watermark_attachment_file - file
+#   bundle_watermark_attachment_delete - boolean - If true, will delete the file stored in bundle_watermark_attachment
 #   disable_2fa_with_delay - boolean - If set to true, we will begin the process of disabling 2FA on this site.
 #   ldap_password_change - string - New LDAP password.
 #   ldap_password_change_confirmation - string - Confirm new LDAP password.
@@ -283,6 +294,8 @@ def update(params = None, options = None):
         raise InvalidParameterError("Bad parameter: subdomain must be an str")
     if "domain" in params and not isinstance(params["domain"], str):
         raise InvalidParameterError("Bad parameter: domain must be an str")
+    if "domain_letsencrypt_chain" in params and not isinstance(params["domain_letsencrypt_chain"], str):
+        raise InvalidParameterError("Bad parameter: domain_letsencrypt_chain must be an str")
     if "email" in params and not isinstance(params["email"], str):
         raise InvalidParameterError("Bad parameter: email must be an str")
     if "reply_to_email" in params and not isinstance(params["reply_to_email"], str):
