@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -9,6 +10,7 @@ class UsageSnapshot:
         'start_at': None,     # date-time - Site usage report start date/time
         'end_at': None,     # date-time - Site usage report end date/time
         'created_at': None,     # date-time - Site usage report created at date/time
+        'high_water_user_count': None,     # double - Site usage report highest usage in time period
         'current_storage': None,     # double - Current site usage as of report
         'high_water_storage': None,     # double - Site usage report highest usage in time period
         'total_downloads': None,     # int64 - Number of downloads in report time period
@@ -37,7 +39,7 @@ class UsageSnapshot:
 
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 def list(params = None, options = None):
     if not isinstance(params, dict):
